"""Time-range simulation module."""

from .time_range import simulate_time_range, SunDataPoint, SimulationResult, HitInterval

__all__ = [
    "simulate_time_range",
    "SunDataPoint",
    "SimulationResult",
    "HitInterval",
]
